@@ -20,8 +20,16 @@ for modules, dependencies in (
             "abjad_constants",
             "abjad",
         ),
-        ("abjad", "abjadext.nauert"),
+        ("abjad", "abjadext.nauert", "abjadext.rmakers"),
     ),
+    # for future
+    # (
+    #     (
+    #         "abjad_video_constants",
+    #         "abjad_video",
+    #     ),
+    #     ("abjad", "PIL"),
+    # ),
 ):
     for module in modules:
         tools.import_module_if_dependencies_have_been_installed(
