@@ -1,6 +1,10 @@
 """Convert mutwo or generic Python objects to other mutwo or generic Python objects."""
 
+from . import time_brackets_constants
+
 from . import loudness
 from . import metricities
 from . import playing_indicators
+from . import spectrals
 from . import tempos
+from . import time_brackets
